@@ -48,6 +48,7 @@ pub struct MetadataSet {
 /// For more information, see [Metadata Files](http://docs.sublimetext.info/en/latest/reference/metadata.html)
 #[derive(Debug, Clone, Serialize, Deserialize, PartialEq)]
 #[serde(rename_all = "camelCase")]
+#[non_exhaustive]
 pub struct MetadataItems {
     pub increase_indent_pattern: Option<Regex>,
     pub decrease_indent_pattern: Option<Regex>,
@@ -64,9 +65,6 @@ pub struct MetadataItems {
     /// The first pair of `TM_COMMENT_START` and `TM_COMMENT_END` items in
     /// `shell_variables`, if they exist.
     pub block_comment: Option<(String, String)>,
-
-    #[serde(default)]
-    __allow_adding_fields_without_major_semver_bump: (),
 }
 
 /// A type that can be deserialized from a `.tmPreferences` file.
@@ -346,7 +344,7 @@ impl<'a> ScopedMetadata<'a> {
 
     pub fn line_comment(&self) -> Option<&str> {
         let idx = self.items.iter().position(|m| m.1.items.line_comment.is_some())?;
-        self.items[idx].1.items.line_comment.as_ref().map(|s| s.as_str())
+        self.items[idx].1.items.line_comment.as_deref()
     }
 
     pub fn block_comment(&self) -> Option<(&str, &str)> {
@@ -404,7 +402,7 @@ impl<'de> Deserialize<'de> for MetadataSet {
         let MetaSetSerializable { selector_string, items } = inner;
         let selector = ScopeSelectors::from_str(&selector_string)
             .map_err(|e| Error::custom(format!("{:?}", e)))?;
-        let items = items.ok_or_else(|| Error::custom(format!("no metadata items")))?;
+        let items = items.ok_or_else(|| Error::custom("no metadata items".to_string()))?;
         Ok(MetadataSet { selector_string, selector, items })
     }
 }
@@ -488,12 +486,12 @@ mod tests {
         let indent_ctx = ps.metadata.metadata_for_scope(&rust_scopes);
 
         assert_eq!(indent_ctx.items.len(), 1, "failed to load rust metadata");
-        assert_eq!(indent_ctx.increase_indent("struct This {"), true);
-        assert_eq!(indent_ctx.increase_indent("struct This }"), false);
-        assert_eq!(indent_ctx.decrease_indent("     }"), true);
-        assert_eq!(indent_ctx.decrease_indent("struct This {"), false);
-        assert_eq!(indent_ctx.decrease_indent("struct This {}"), false);
-        assert_eq!(indent_ctx.increase_indent("struct This {}"), false);
+        assert!(indent_ctx.increase_indent("struct This {"));
+        assert!(!indent_ctx.increase_indent("struct This }"));
+        assert!(indent_ctx.decrease_indent("     }"));
+        assert!(!indent_ctx.decrease_indent("struct This {"));
+        assert!(!indent_ctx.decrease_indent("struct This {}"));
+        assert!(!indent_ctx.increase_indent("struct This {}"));
 
     }
 }
