@@ -11,6 +11,14 @@ use std::mem;
 use serde::{Deserialize, Deserializer, Serialize, Serializer};
 use serde::de::{Error, Visitor};
 
+/// Scope related errors
+#[derive(Debug, thiserror::Error)]
+#[non_exhaustive]
+pub enum ScopeError {
+    #[error("Tried to restore cleared scopes, but none were cleared")]
+    NoClearedScopesToRestore,
+}
+
 /// Multiplier on the power of 2 for MatchPower. This is only useful if you compute your own
 /// [`MatchPower`] scores
 ///
@@ -48,13 +56,16 @@ pub struct Scope {
 }
 
 /// Not all strings are valid scopes
-#[derive(Debug)]
+#[derive(Debug, thiserror::Error)]
+#[non_exhaustive]
 pub enum ParseScopeError {
     /// Due to a limitation of the current optimized internal representation
     /// scopes can be at most 8 atoms long
+    #[error("Too long scope. Scopes can be at most 8 atoms long.")]
     TooLong,
     /// The internal representation uses 16 bits per atom, so if all scopes ever
     /// used by the program have more than 2^16-2 atoms, things break
+    #[error("Too many atoms. Max 2^16-2 atoms allowed.")]
     TooManyAtoms,
 }
 
@@ -175,7 +186,7 @@ impl ScopeRepository {
                 break;
             }
             if i != 0 {
-                s.push_str(".");
+                s.push('.');
             }
             s.push_str(self.atom_str(atom_number));
         }
@@ -216,6 +227,7 @@ impl Scope {
     /// I can't think of any reason you'd find this useful. It is used internally for turning a
     /// scope back into a string.
     pub fn atom_at(self, index: usize) -> u16 {
+        #[allow(clippy::panic)] // The below panic is too much of an edge-case for it to be worth propagating
         let shifted = if index < 4 {
             self.a >> ((3 - index) * 16)
         } else if index < 8 {
@@ -242,7 +254,7 @@ impl Scope {
         8 - self.missing_atoms()
     }
 
-    pub fn is_empty(&self) -> bool {
+    pub fn is_empty(self) -> bool {
         self.len() == 0
     }
 
@@ -358,6 +370,7 @@ pub struct MatchPower(pub f64);
 
 impl Eq for MatchPower {}
 
+#[allow(clippy::derive_ord_xor_partial_ord)] // The code works, so let's keep using it
 impl Ord for MatchPower {
     fn cmp(&self, other: &Self) -> Ordering {
         self.partial_cmp(other).unwrap()
@@ -394,7 +407,7 @@ impl ScopeStack {
     /// Modifies this stack according to the operation given
     ///
     /// Use this to create a stack from a `Vec` of changes given by the parser.
-    pub fn apply(&mut self, op: &ScopeStackOp) {
+    pub fn apply(&mut self, op: &ScopeStackOp) -> Result<(), ScopeError> {
         self.apply_with_hook(op, |_,_|{})
     }
 
@@ -406,7 +419,7 @@ impl ScopeStack {
     /// [`apply`]: #method.apply
     /// [`BasicScopeStackOp`]: enum.BasicScopeStackOp.html
     #[inline]
-    pub fn apply_with_hook<F>(&mut self, op: &ScopeStackOp, mut hook: F)
+    pub fn apply_with_hook<F>(&mut self, op: &ScopeStackOp, mut hook: F) -> Result<(), ScopeError>
         where F: FnMut(BasicScopeStackOp, &[Scope])
     {
         match *op {
@@ -447,11 +460,13 @@ impl ScopeStack {
                             hook(BasicScopeStackOp::Push(*s), self.as_slice());
                         }
                     }
-                    None => panic!("tried to restore cleared scopes, but none were cleared"),
+                    None => return Err(ScopeError::NoClearedScopesToRestore),
                 }
             }
             ScopeStackOp::Noop => (),
         }
+
+        Ok(())
     }
 
     /// Prints out each scope in the stack separated by spaces
